==> smallrye-open-api-core-2.1.7-sources.jar: io/smallrye/openapi/runtime/scanner/ScannerLogging_$logger.java <==
package io.smallrye.openapi.runtime.scanner;

import java.util.Locale;
import java.io.Serializable;
import org.jboss.jandex.Type;
import org.jboss.logging.DelegatingBasicLogger;
import org.jboss.logging.BasicLogger;
import java.lang.String;
import org.jboss.logging.Logger;
import org.jboss.jandex.DotName;
import org.jboss.jandex.ClassInfo;


import static org.jboss.logging.Logger.Level.INFO;
import static org.jboss.logging.Logger.Level.DEBUG;
import static org.jboss.logging.Logger.Level.WARN;

/**
 * Warning this class consists of generated code.
 */
public class ScannerLogging_$logger extends DelegatingBasicLogger implements ScannerLogging, BasicLogger, Serializable {
    private static final long serialVersionUID = 1L;
    private static final String FQCN = ScannerLogging_$logger.class.getName();
    public ScannerLogging_$logger(final Logger log) {
        super(log);
    }
    private static final Locale LOCALE = Locale.ROOT;
    protected Locale getLoggingLocale() {
        return LOCALE;
    }
    @Override
    public final void scanning(final String annotationType) {
        super.log.logf(FQCN, DEBUG, null, scanning$str(), annotationType);
    }
    protected String scanning$str() {
        return "SROAP04000: Scanning deployment for %s Annotations.";
    }
    @Override
    public final void startProcessing(final DotName root) {
        super.log.logf(FQCN, DEBUG, null, startProcessing$str(), root);
    }
    protected String startProcessing$str() {
        return "SROAP04001: Starting processing with root: %s";
    }
    @Override
    public final void gettingFields(final Type type, final ClassInfo classInfo) {
        super.log.logf(FQCN, DEBUG, null, gettingFields$str(), type, classInfo);
    }
    protected String gettingFields$str() {
        return "SROAP04002: Getting all fields for: %s in class: %s";
    }
    @Override
    public final void errorParsingSchema(final String className) {
        super.log.logf(FQCN, WARN, null, errorParsingSchema$str(), className);
    }
    protected String errorParsingSchema$str() {
        return "SROAP04003: Configured schema for %s could not be parsed";
    }
    @Override
    public final void configSchemaRegistered(final String className) {
        super.log.logf(FQCN, INFO, null, configSchemaRegistered$str(), className);
    }
    protected String configSchemaRegistered$str() {
        return "SROAP04004: Configured schema for %s has been registered";
    }
    @Override
    public final void schemaTypeNotFound(final DotName className) {
        super.log.logf(FQCN, WARN, null, schemaTypeNotFound$str(), className);
    }
    protected String schemaTypeNotFound$str() {
        return "SROAP04005: Could not find schema class in index: %s";
    }
}

==> smallrye-open-api-core-3.8.0-sources.jar: io/smallrye/openapi/runtime/scanner/ScannerLogging_$logger.java <==
package io.smallrye.openapi.runtime.scanner;

import java.util.Locale;
import java.io.Serializable;
import org.jboss.jandex.Type;
import org.jboss.logging.DelegatingBasicLogger;
import org.jboss.logging.BasicLogger;
import java.lang.Throwable;
import java.lang.String;
import org.jboss.logging.Logger;
import org.jboss.jandex.DotName;
import org.jboss.jandex.ClassInfo;


import static org.jboss.logging.Logger.Level.INFO;
import static org.jboss.logging.Logger.Level.DEBUG;
import static org.jboss.logging.Logger.Level.WARN;

/**
 * Warning this class consists of generated code.
 */
public class ScannerLogging_$logger extends DelegatingBasicLogger implements ScannerLogging, BasicLogger, Serializable {
    private static final long serialVersionUID = 1L;
    private static final String FQCN = ScannerLogging_$logger.class.getName();
    public ScannerLogging_$logger(final Logger log) {
        super(log);
    }
    private static final Locale LOCALE = Locale.ROOT;
    protected Locale getLoggingLocale() {
        return LOCALE;
    }
    @Override
    public final void scanning(final String annotationType) {
        super.log.logf(FQCN, DEBUG, null, scanning$str(), annotationType);
    }
    protected String scanning$str() {
        return "SROAP04000: Scanning deployment for %s Annotations.";
    }
    @Override
    public final void startProcessing(final DotName root) {
        super.log.logf(FQCN, DEBUG, null, startProcessing$str(), root);
    }
    protected String startProcessing$str() {
        return "SROAP04001: Starting processing with root: %s";
    }
    @Override
    public final void gettingFields(final Type type, final ClassInfo classInfo) {
        super.log.logf(FQCN, DEBUG, null, gettingFields$str(), type, classInfo);
    }
    protected String gettingFields$str() {
        return "SROAP04002: Getting all fields for: %s in class: %s";
    }
    @Override
    public final void errorParsingSchema(final String className) {
        super.log.logf(FQCN, WARN, null, errorParsingSchema$str(), className);
    }
    protected String errorParsingSchema$str() {
        return "SROAP04003: Configured schema for %s could not be parsed";
    }
    @Override
    public final void configSchemaRegistered(final String className) {
        super.log.logf(FQCN, INFO, null, configSchemaRegistered$str(), className);
    }
    protected String configSchemaRegistered$str() {
        return "SROAP04004: Configured schema for %s has been registered";
    }
    @Override
    public final void schemaTypeNotFound(final DotName className) {
        super.log.logf(FQCN, WARN, null, schemaTypeNotFound$str(), className);
    }
    protected String schemaTypeNotFound$str() {
        return "SROAP04005: Could not find schema class in index: %s";
    }
    @Override
    public final void configSchemaTypeInvalid(final String typeSignature, final Throwable cause) {
        super.log.logf(FQCN, WARN, cause, configSchemaTypeInvalid$str(), typeSignature);
    }
    protected String configSchemaTypeInvalid$str() {
        return "SROAP04006: Configured schema type %s is not a valid type signature";
    }
}
